@@ -18,8 +18,13 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 #
 
+
+module APRS4R
+  APRS4RVersion = [0, 8, 1].join( '.')
+end
+
 path = ENV['APRS4R_ETC']
-path = "/etc" unless ENV['APRS4R_ETC']
+path = "/etc/aprs4r" unless ENV['APRS4R_ETC']
 
 require 'Logger'
 require 'Log4rConfigurator'
