@@ -26,7 +26,7 @@ class ISSocketConfiguration < SocketConfiguration
 
 
   def to_yaml_properties
-    %w{ @name @type @enable @host @port @username @filter @timeout}
+    %w{ super @host @port @username @filter @timeout}
   end
 
 end
